@@ -11,7 +11,7 @@ def writeChannels(chanInfo, bak=backUpVals):
     # parameter is required.
     for ch in chanInfo['channels']:
         if not isinstance(chanInfo['channels'][ch], dict):
-            chanInfo['channels'][ch] = {'value': chanInfo[ch]}
+            chanInfo['channels'][ch] = {'value': chanInfo['channels'][ch]}
         else:
             if 'value' not in chanInfo['channels'][ch]:
                 raise RuntimeError('No value found for ' + ch)
@@ -30,6 +30,7 @@ def writeChannels(chanInfo, bak=backUpVals):
             curVals[arg] = chanInfo[arg]
     curVals['channels'] = {}
     for ch in chanInfo['channels']:
+        curVals['channels'][ch] = {}
         for key in chanInfo['channels'][ch]:
             if key == 'value':
                 curVals['channels'][ch][key] = caget(ch)
